@@ -3,7 +3,7 @@
  *
  * $Header$
  *
- * pgpool: a language independent connection pool server for PostgreSQL 
+ * pgpool: a language independent connection pool server for PostgreSQL
  * written by Tatsuo Ishii
  *
  * Copyright (c) 2003-2021	PgPool Global Development Group
@@ -29,31 +29,33 @@
 #include "pool_config.h"		/* remove me afterwards */
 
 static POOL_PROCESS_CONTEXT process_context_d;
-static POOL_PROCESS_CONTEXT *process_context;
+static POOL_PROCESS_CONTEXT * process_context;
 
 /*
  * Initialize per process context
  */
-void pool_init_process_context(void)
+void
+pool_init_process_context(void)
 {
 	process_context = &process_context_d;
 
 	if (!process_info)
 		ereport(FATAL,
-			(return_code(1),
+				(return_code(1),
 				 errmsg("process info is not set")));
 	process_context->process_info = process_info;
 
 	if (!pool_config->backend_desc)
 		ereport(FATAL,
-			(return_code(1),
+				(return_code(1),
 				 errmsg("backend desc is not set")));
 
 	process_context->backend_desc = pool_config->backend_desc;
 
 	process_context->proc_id = my_proc_id;
 
-	process_context->local_session_id = 0;		/* initialize local session counter */
+	process_context->local_session_id = 0;	/* initialize local session
+											 * counter */
 
 	process_context->last_alarm_handler = SIG_IGN;
 	process_context->last_alarm_time = 0;
@@ -64,7 +66,8 @@ void pool_init_process_context(void)
 /*
  * Return process context
  */
-POOL_PROCESS_CONTEXT *pool_get_process_context(void)
+POOL_PROCESS_CONTEXT *
+pool_get_process_context(void)
 {
 	return process_context;
 }
@@ -72,11 +75,12 @@ POOL_PROCESS_CONTEXT *pool_get_process_context(void)
 /*
  * Return my process info
  */
-ProcessInfo *pool_get_my_process_info(void)
+ProcessInfo *
+pool_get_my_process_info(void)
 {
 	if (!process_context)
 		ereport(FATAL,
-			(return_code(1),
+				(return_code(1),
 				 errmsg("process context is not initialized")));
 
 	return &process_context->process_info[process_context->proc_id];
@@ -85,7 +89,8 @@ ProcessInfo *pool_get_my_process_info(void)
 /*
  * Increment local session id
  */
-void pool_incremnet_local_session_id(void)
+void
+pool_incremnet_local_session_id(void)
 {
 	POOL_PROCESS_CONTEXT *p = pool_get_process_context();
 
@@ -122,9 +127,11 @@ pool_coninfo_size(void)
 /*
  * Return number of elements of connection info(ConnectionInfo) on shmem.
  */
-int pool_coninfo_num(void)
+int
+pool_coninfo_num(void)
 {
-	int nelm;
+	int			nelm;
+
 	nelm = pool_config->num_init_children *
 		pool_config->max_pool *
 		MAX_NUM_BACKENDS;
@@ -136,12 +143,13 @@ int pool_coninfo_num(void)
  * Return pointer to i th child, j th connection pool and k th backend
  * of connection info on shmem.
  */
-ConnectionInfo *pool_coninfo(int child, int connection_pool, int backend)
+ConnectionInfo *
+pool_coninfo(int child, int connection_pool, int backend)
 {
 	if (child < 0 || child >= pool_config->num_init_children)
 	{
 		ereport(WARNING,
-			(errmsg("failed to get connection info, invalid child number: %d", child)));
+				(errmsg("failed to get connection info, invalid child number: %d", child)));
 		return NULL;
 	}
 
@@ -159,8 +167,8 @@ ConnectionInfo *pool_coninfo(int child, int connection_pool, int backend)
 		return NULL;
 	}
 
-	return &con_info[child*pool_config->max_pool*MAX_NUM_BACKENDS+
-					 connection_pool*MAX_NUM_BACKENDS+
+	return &con_info[child * pool_config->max_pool * MAX_NUM_BACKENDS +
+					 connection_pool * MAX_NUM_BACKENDS +
 					 backend];
 }
 
@@ -168,10 +176,11 @@ ConnectionInfo *pool_coninfo(int child, int connection_pool, int backend)
  * Return pointer to child which has OS process id pid, j th connection
  * pool and k th backend of connection info on shmem.
  */
-ConnectionInfo *pool_coninfo_pid(int pid, int connection_pool, int backend)
+ConnectionInfo *
+pool_coninfo_pid(int pid, int connection_pool, int backend)
 {
-	int child = -1;
-	int		i;
+	int			child = -1;
+	int			i;
 
 	for (i = 0; i < pool_config->num_init_children; i++)
 	{
@@ -183,19 +192,19 @@ ConnectionInfo *pool_coninfo_pid(int pid, int connection_pool, int backend)
 	}
 
 	if (child < 0)
-		elog(ERROR,"failed to get child pid, invalid child PID:%d",pid);
+		elog(ERROR, "failed to get child pid, invalid child PID:%d", pid);
 
 	if (child < 0 || child >= pool_config->num_init_children)
-		elog(ERROR,"failed to get child pid, invalid child no:%d",child);
+		elog(ERROR, "failed to get child pid, invalid child no:%d", child);
 
 	if (connection_pool < 0 || connection_pool >= pool_config->max_pool)
-		elog(ERROR,"failed to get child pid, invalid connection pool no:%d",connection_pool);
+		elog(ERROR, "failed to get child pid, invalid connection pool no:%d", connection_pool);
 
 	if (backend < 0 || backend >= MAX_NUM_BACKENDS)
-		elog(ERROR,"failed to get child pid, invalid backend no:%d",backend);
+		elog(ERROR, "failed to get child pid, invalid backend no:%d", backend);
 
-	return &con_info[child*pool_config->max_pool*MAX_NUM_BACKENDS+
-					 connection_pool*MAX_NUM_BACKENDS+
+	return &con_info[child * pool_config->max_pool * MAX_NUM_BACKENDS +
+					 connection_pool * MAX_NUM_BACKENDS +
 					 backend];
 }
 
@@ -205,32 +214,35 @@ ConnectionInfo *pool_coninfo_pid(int pid, int connection_pool, int backend)
  * if the connection is found the *backend_node_id contains the backend node id
  * of the backend node that has the connection
  */
-ConnectionInfo* pool_coninfo_backend_pid(int backend_pid, int* backend_node_id)
+ConnectionInfo *
+pool_coninfo_backend_pid(int backend_pid, int *backend_node_id)
 {
-	int child;
+	int			child;
+
 	/*
-	 * look for the child process that has the backend
-	 * with the pid
+	 * look for the child process that has the backend with the pid
 	 */
 
 	ereport(DEBUG1,
-			(errmsg("searching for the connection with backend pid:%d",backend_pid)));
+			(errmsg("searching for the connection with backend pid:%d", backend_pid)));
 
 	for (child = 0; child < pool_config->num_init_children; child++)
 	{
-		int pool;
+		int			pool;
 		ProcessInfo *pi = pool_get_process_info(process_info[child].pid);
 
 		for (pool = 0; pool < pool_config->max_pool; pool++)
 		{
-			int backend_id;
+			int			backend_id;
+
 			for (backend_id = 0; backend_id < NUM_BACKENDS; backend_id++)
 			{
-				int poolBE = pool*MAX_NUM_BACKENDS+backend_id;
+				int			poolBE = pool * MAX_NUM_BACKENDS + backend_id;
+
 				if (ntohl(pi->connection_info[poolBE].pid) == backend_pid)
 				{
 					ereport(DEBUG1,
-							(errmsg("found for the connection with backend pid:%d on backend node %d",backend_pid,backend_id)));
+							(errmsg("found for the connection with backend pid:%d on backend node %d", backend_pid, backend_id)));
 					*backend_node_id = backend_id;
 					return &pi->connection_info[poolBE];
 				}
@@ -245,12 +257,14 @@ ConnectionInfo* pool_coninfo_backend_pid(int backend_pid, int* backend_node_id)
  * backend and it should not be considered as a backend node failure.
  * This flag is used to handle pg_terminate_backend()
  */
-void pool_set_connection_will_be_terminated(ConnectionInfo* connInfo)
+void
+pool_set_connection_will_be_terminated(ConnectionInfo * connInfo)
 {
 	connInfo->swallow_termination = 1;
 }
 
-void pool_unset_connection_will_be_terminated(ConnectionInfo* connInfo)
+void
+pool_unset_connection_will_be_terminated(ConnectionInfo * connInfo)
 {
 	connInfo->swallow_termination = 0;
 }
@@ -258,12 +272,13 @@ void pool_unset_connection_will_be_terminated(ConnectionInfo* connInfo)
 /*
  * Set frontend connected flag
  */
-void pool_coninfo_set_frontend_connected(int proc_id, int pool_index)
+void
+pool_coninfo_set_frontend_connected(int proc_id, int pool_index)
 {
 	ConnectionInfo *con;
-	int i;
+	int			i;
 
-	for (i=0;i<NUM_BACKENDS;i++)
+	for (i = 0; i < NUM_BACKENDS; i++)
 	{
 		if (!VALID_BACKEND(i))
 			continue;
@@ -272,7 +287,7 @@ void pool_coninfo_set_frontend_connected(int proc_id, int pool_index)
 
 		if (con == NULL)
 		{
-			elog(WARNING,"failed to get connection info while marking the frontend is connected for pool");
+			elog(WARNING, "failed to get connection info while marking the frontend is connected for pool");
 			return;
 		}
 		con->connected = true;
@@ -282,12 +297,13 @@ void pool_coninfo_set_frontend_connected(int proc_id, int pool_index)
 /*
  * Unset frontend connected flag
  */
-void pool_coninfo_unset_frontend_connected(int proc_id, int pool_index)
+void
+pool_coninfo_unset_frontend_connected(int proc_id, int pool_index)
 {
 	ConnectionInfo *con;
-	int i;
+	int			i;
 
-	for (i=0;i<NUM_BACKENDS;i++)
+	for (i = 0; i < NUM_BACKENDS; i++)
 	{
 		if (!VALID_BACKEND(i))
 			continue;
@@ -296,7 +312,7 @@ void pool_coninfo_unset_frontend_connected(int proc_id, int pool_index)
 
 		if (con == NULL)
 		{
-			elog(WARNING,"failed to get connection info while marking the frontend is not connected for pool");
+			elog(WARNING, "failed to get connection info while marking the frontend is not connected for pool");
 			return;
 		}
 		con->connected = false;
@@ -308,10 +324,11 @@ void pool_coninfo_unset_frontend_connected(int proc_id, int pool_index)
  * For pool_alarm_undo(), the alarm second and the old handler
  * are saved, and the remaining time is calculated.
  */
-void pool_alarm(pool_sighandler_t handler, unsigned int second)
+void
+pool_alarm(pool_sighandler_t handler, unsigned int second)
 {
 	POOL_PROCESS_CONTEXT *p = pool_get_process_context();
-	time_t	now = time(NULL);
+	time_t		now = time(NULL);
 
 	alarm(second);
 	p->last_alarm_handler = pool_signal(SIGALRM, handler);
@@ -320,7 +337,7 @@ void pool_alarm(pool_sighandler_t handler, unsigned int second)
 	{
 		p->undo_alarm_second = p->last_alarm_second - (now - p->last_alarm_time);
 		if (p->undo_alarm_second <= 0)
-		  p->undo_alarm_second = 1;
+			p->undo_alarm_second = 1;
 	}
 
 	p->last_alarm_time = now;
@@ -330,7 +347,8 @@ void pool_alarm(pool_sighandler_t handler, unsigned int second)
 /*
  * Undo the alarm signal handler using the remaining time.
  */
-void pool_undo_alarm(void)
+void
+pool_undo_alarm(void)
 {
 	POOL_PROCESS_CONTEXT *p = pool_get_process_context();
 
