@@ -30,12 +30,12 @@ do
 	# start pgpool-II
 	./startall
 
-	sleep 1
+	wait_for_pgpool_startup
 
 	# initialize tables
 	$PGBENCH -i test
 
-	$PGBENCH -S -T 10 test
+	$PGBENCH -S -T 1 test
 	
 	# find pgpool-II child process id and grab initial process size (virtual size)
 	foo=`ps x|grep "pgpool: wait for connection request"`
