@@ -65,8 +65,8 @@ pool_shared_memory_create(size_t size)
 
 	if (memAddress == (void *) -1)
 		ereport(FATAL,
-			(errmsg("could not create shared memory for request size: %ld",size),
-				errdetail("attach to shared memory [id:%d] failed with reason: \"%s\"",shmid,strerror(errno))));
+				(errmsg("could not create shared memory for request size: %ld", size),
+				 errdetail("attach to shared memory [id:%d] failed with reason: \"%m\"", shmid)));
 
 
 	/* Register on-exit routine to detach new segment before deleting */
@@ -84,8 +84,8 @@ IpcMemoryDetach(int status, Datum shmaddr)
 {
 	if (shmdt((void *) shmaddr) < 0)
 		ereport(LOG,
-			(errmsg("removing shared memory segments"),
-				 errdetail("shmdt(%p) failed: %s", (void *) shmaddr, strerror(errno))));
+				(errmsg("removing shared memory segments"),
+				 errdetail("shmdt(%p) failed: %m", (void *) shmaddr)));
 
 }
 
@@ -96,24 +96,24 @@ IpcMemoryDetach(int status, Datum shmaddr)
 static void
 IpcMemoryDelete(int status, Datum shmId)
 {
-  	struct shmid_ds shmStat;
+	struct shmid_ds shmStat;
 
-  	/*
-  	 * Is a previously-existing shmem segment still existing and in use?
-  	 */
-  	if (shmctl(shmId, IPC_STAT, &shmStat) < 0
-  		&& (errno == EINVAL || errno == EACCES))
-  		return;
+	/*
+	 * Is a previously-existing shmem segment still existing and in use?
+	 */
+	if (shmctl(shmId, IPC_STAT, &shmStat) < 0
+		&& (errno == EINVAL || errno == EACCES))
+		return;
 #ifdef NOT_USED
-  	else if (shmStat.shm_nattch != 0)
-  		return;
+	else if (shmStat.shm_nattch != 0)
+		return;
 #endif
 
 	if (shmctl(shmId, IPC_RMID, NULL) < 0)
 		ereport(LOG,
-			(errmsg("deleting shared memory segments"),
-				errdetail("shmctl(%lu, %d, 0) failed: %s",
-					   shmId, IPC_RMID, strerror(errno))));
+				(errmsg("deleting shared memory segments"),
+				 errdetail("shmctl(%lu, %d, 0) failed with error \"%m\"",
+						   shmId, IPC_RMID)));
 }
 
 void
